"use strict";
const gulp = require("gulp"),
    tsc = require("gulp-typescript"),
    yarn = require("gulp-yarn"),
    tslint = require("gulp-tslint"),
    gutil = require('gulp-util'),
    merge = require('merge2');

const tsProject = tsc.createProject("tsconfig.json");

gulp.task("lint", function () {
    const config = { formatter: "verbose", emitError: (process.env.CI) ? true : false };
    return tsProject.src()
        .pipe(tslint(config))
        .pipe(tslint.report());
});

gulp.task('yarn', function () {
    return gulp.src(['./package.json', './yarn.lock'])
        .pipe(gulp.dest('.'))
        .on('error', gutil.log)
        .pipe(yarn({
            production: true
        }))
        .on('error', gutil.log);
});

gulp.task('ts-compile', function () {
    var tsResult = tsProject.src()
        .pipe(tsProject())
        .on('error', gutil.log);

    return merge([
        tsResult.dts.pipe(gulp.dest(tsProject.options.outDir)),
        tsResult.js.pipe(gulp.dest(tsProject.options.outDir))
    ]);
});

gulp.task('copy-assets', function () {
    gulp.src(['src/assets/**/*', '!src/assets/**/*.ts'])
        .pipe(gulp.dest(tsProject.options.outDir + '/assets'))
        .on('error', gutil.log);
});

gulp.task('watch', ['copy-assets', 'ts-compile'], function () {
    gulp.watch(["src/**/*", "test/**/*.ts"], ['copy-assets', 'ts-compile'])
        .on('error', gutil.log);
});

gulp.task("default", function (cb) {
    runSequence("yarn", "lint", "copy-assets", "ts-compile", "binary", cb)
        .on('error', gutil.log);
});
