"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const process = require("process");
const chalk_1 = require("chalk");
const cli_1 = require("../cli");
const session_1 = require("../session");
const utils_1 = require("../utils");
exports.command = 'init';
exports.desc = 'Install Snips Platform components';
exports.builder = {
    verbose: {
        demandOption: false,
        describe: 'Include remote logs',
        type: 'boolean',
        alias: 'v',
    },
};
exports.handler = (argv) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const verbose = JSON.parse(JSON.stringify(argv)).verbose;
    cli_1.default.stream.println('Installing Snips Platform components. This may take a few minutes...');
    const ssh = new session_1.SSHService();
    yield ssh.connect()
        .catch(e => {
        cli_1.default.stream.stop();
        cli_1.default.stream.error(e);
        process.exit();
    });
    yield utils_1.timeout(500);
    let firstPass = true;
    try {
        yield ssh.installSnips(log => { if (verbose)
            cli_1.default.stream.print(log); }, stepTitle => {
            if (verbose) {
                cli_1.default.stream.println(chalk_1.default.green(stepTitle));
            }
            else {
                if (!firstPass)
                    cli_1.default.stream.success();
                cli_1.default.stream.loading(stepTitle);
                firstPass = false;
            }
        });
    }
    catch (e) {
        cli_1.default.stream.stop();
        cli_1.default.stream.error('Failed to install platform: ' + e.stack);
        ssh.disconnect();
        process.exit();
    }
    ssh.disconnect();
    cli_1.default.stream.success('Successfully installed the Snips Platform');
    cli_1.default.stream.hint('You can now setup your audio with ' + chalk_1.default.blue('sam setup audio'));
});
