import { DeviceCredentials, AssistantFile, Snipsfile } from '../models';
import { AudioDevice } from '../utils';
export declare const snipsRemoteAuthorizedKeysFilename = "~/.ssh/authorized_keys";
export declare enum SnipsServices {
    analytics = "snips-analytics",
    asr = "snips-asr",
    audioServer = "snips-audio-server",
    dialogue = "snips-dialogue",
    hotword = "snips-hotword",
    nlu = "snips-nlu",
    skillServer = "snips-skill-server",
    template = "snips-template",
    tts = "snips-tts",
    watch = "snips-watch",
}
export declare const availableSnipsServices: string[];
export declare class SSHService {
    ssh: any;
    credentials: DeviceCredentials;
    constructor();
    connect(): Promise<string>;
    retryConnect(tick: (numberOfRetries: number) => void, limit?: number): Promise<boolean>;
    newConnection(credentials: DeviceCredentials, password: string, onConnected: () => void, onSSHCopyId: () => void, onCredentialsSaved: () => void, onSSHKeygenExeNotFound: (path: string) => Promise<string>): Promise<void>;
    private connectInternal(credentials, password?);
    disconnect(): Promise<void>;
    reboot(): Promise<void>;
    writeFile(contents: string, remotePath: string): any;
    writeFileAsRoot(contents: string, remotePath: string): Promise<any>;
    isAssistantInstalled(): Promise<boolean>;
    getInstalledAssistant(): Promise<AssistantFile>;
    getOSVersion(): Promise<string>;
    installSnipsPlatformDemo(listener: (output: string) => void): Promise<string>;
    aptGetY(packageNames: string[], listener: (output: string) => void): Promise<string>;
    isNetcatInstalled(): Promise<boolean>;
    speakerTest(): Promise<string>;
    stopSpeakerTest(): Promise<string>;
    setHostname(newHostname: string): Promise<string>;
    static fetchBootHostname(ips: string[]): Promise<{
        ip: string;
        hostname: string;
        snipsHostname: string;
    }[]>;
    getCaptureLevel(card?: number | undefined): Promise<string>;
    setCaptureLevel(card?: number | undefined, level?: number | undefined): Promise<string>;
    getVolumeLevel(card?: number | undefined): Promise<string>;
    setVolumeLevel(card?: number | undefined, level?: number | undefined): Promise<string>;
    recordAudio(name: string): Promise<string>;
    stopRecording(): Promise<string>;
    testingtesting(): Promise<string>;
    listCaptureDevices(): Promise<AudioDevice[]>;
    listOuputDevices(): Promise<AudioDevice[]>;
    launchSnipsWatch(listener: (string) => void): Promise<string>;
    journalctlLogs(services: string[] | undefined, listener: (string) => void): Promise<string>;
    snipsServicesSystemctlStatus(): Promise<{
        name: string;
        active: boolean;
    }[]>;
    systemctlStatus(service: string): Promise<boolean>;
    playAudio(name: string): Promise<string>;
    removeAudioFile(name: string): Promise<string>;
    setupAsoundConf(outputDevice: AudioDevice, captureDevice: AudioDevice): Promise<string>;
    getAssistantSnipsfile(): Promise<Snipsfile>;
    copySnipsfile(snipsfile: string): Promise<any>;
    stopService(service: string): Promise<string>;
    stopServices(services?: string[] | undefined): Promise<string>;
    relaunchService(service: string): Promise<string>;
    startServices(services?: string[] | undefined): Promise<string>;
    relaunchServices(services?: string[] | undefined): Promise<string>;
    updateSnips(listener: (string) => void): Promise<string>;
    installSnips(listener: (string) => void, installSteps: (string) => void): Promise<string>;
    packagesVersion(): Promise<{
        name: string;
        version: string;
    }[]>;
    updateWifi(name: string, passphrase: string): Promise<string>;
    statusWifi(): Promise<string>;
    reconnectWifi(): Promise<string>;
    disconnectWifi(): Promise<string>;
    putFile(localPath: string, remotePath: string): Promise<string>;
    putString(string: string, remotePath: string): Promise<any>;
    getFile(remotePath: string): Promise<string>;
    putDirectory(localDirectory: string, remoteDirectory: string): Promise<string>;
    removeFile(remotePath: string): Promise<string>;
    removeDirectory(remotePath: string): Promise<string>;
    unzipFile(filePath: string, destinationPath?: string): Promise<string>;
    installAssistant(assistantPath: string): Promise<string>;
    dpkgCheckIfPackageIsInstalled(packageName: string): Promise<boolean>;
    isFileExecutable(file: string): Promise<boolean>;
    checkCommandExists(command: string): Promise<boolean>;
    installRespeakerMicHat(listener: (string) => void): Promise<string>;
    run(command: string): Promise<string>;
    private sshCommandLog(command, listener);
    snipsTemplateRender(listener: (string) => void): Promise<string>;
    hasSnipsSkillsServerGroup(): Promise<boolean>;
    addCurrentUserToSnipsSkillsAdminGroup(): Promise<string>;
    detectConfigIniParameters(): Promise<string>;
    gitClone(repository: string, branch: string | undefined, listener: (string) => void, permissionError: (string) => void): Promise<void>;
    runSkillSetupSH(skillFolder: any): Promise<string>;
    getSnippets(): Promise<Map<string, {
        type: string;
        snippets: string[];
    }>>;
    getSkillConfig(skillFolder: any): Promise<any>;
    getSkillConfigNew(skillFolder: any): Promise<any>;
    updateSkillConfig(config: any, skillFolder: any): any;
    getGeneratedSkills(): Promise<string[]>;
}
