import * as process from 'process'
import * as yargs from 'yargs'
import chalk from 'chalk'
import cli from '../cli'
import { SSHService } from '../session'
import { timeout } from '../utils'

exports.command = 'init'
exports.desc = 'Install Snips Platform components'

exports.builder = {
    verbose: {
        demandOption: false,
        describe: 'Include remote logs',
        type: 'boolean',
        alias: 'v',
    },
}

exports.handler = async (argv: yargs.Argv) => {
    const verbose = JSON.parse(JSON.stringify(argv)).verbose

    cli.stream.println('Installing Snips Platform components. This may take a few minutes...')

    const ssh = new SSHService()
    await ssh.connect()
    .catch(e => {
        cli.stream.stop()
        cli.stream.error(e)
        process.exit()
    })

    await timeout(500)
    let firstPass = true

    try {
        await ssh.installSnips(
            log => { if (verbose) cli.stream.print(log) },
            stepTitle => {
                if (verbose) {
                    cli.stream.println(chalk.green(stepTitle))
                } else {
                    if (!firstPass) cli.stream.success()
                    cli.stream.loading(stepTitle)
                    firstPass = false
                }
            })
    } catch (e) {
        cli.stream.stop()
        cli.stream.error('Failed to install platform: ' + e.stack)
        ssh.disconnect()
        process.exit()
    }

    ssh.disconnect()

    cli.stream.success('Successfully installed the Snips Platform')
    cli.stream.hint('You can now setup your audio with ' + chalk.blue('sam setup audio'))
}
