import * as yargs from 'yargs'
import { cli } from '../cli'
import { SSHService } from '../session'

exports.command = 'reboot'
exports.desc = 'Reboot the device'

exports.handler = async (_: yargs.Argv) => {
    const ssh = new SSHService()

    await ssh.connect()
    .catch(e => {
        cli.stream.error(e)
        process.exit()
    })

    await ssh.reboot().catch(_ => {})
    let loadingText = 'Waiting for device to reboot'
    cli.stream.loading(loadingText)
    await ssh.retryConnect(() => {
        loadingText += ' . '
        cli.stream.update(loadingText)
    })
    .then(isConnected => {
        if (isConnected) {
            cli.stream.done()
            cli.stream.success('Device has rebooted')
        } else {
            cli.stream.error('Failed to reconnect, try a hard reboot')
        }
    })
    ssh.disconnect()
    process.exit()
}
