import * as yargs from 'yargs'
import { cli } from '../../cli'
import { SSHService, availableSnipsServices } from '../../session'

exports.command = 'log [services...]'
exports.desc = `Control Snips services`
exports.builder = yargs => {
    return yargs
        .positional('services', {
            describe: 'Service(s) to log. If none is provided, it will display all logs.',
            type: 'array',
            choices: availableSnipsServices,
            demandOption: false,
        })
}

exports.handler = async (argv: yargs.Argv) => {
    const services: string[] = JSON.parse(JSON.stringify(argv)).services
    const ssh = new SSHService()
    try {
        await ssh.connect()
        await ssh.journalctlLogs(services, response => cli.stream.print(response))
    } catch (e) {
        cli.stream.error(e)
        process.exit()
    }
    ssh.disconnect()
}
