import * as yargs from 'yargs'
import { cli } from '../../cli'
import { SSHService, availableSnipsServices } from '../../session'

exports.command = 'restart [services...]'
exports.desc = `Restart Snips services`
exports.builder = yargs => {
    return yargs
        .positional('services', {
            describe: 'Service(s) to restart. If none is provided, it will restart all Snips services.',
            type: 'array',
            choices: availableSnipsServices,
            demandOption: false,
        })
}

exports.handler = async (argv: yargs.Argv) => {
    const services: string[] = JSON.parse(JSON.stringify(argv)).services
    const ssh = new SSHService()
    try {
        await ssh.connect()
        await ssh.relaunchServices(services)
    } catch (e) {
        cli.stream.error(e)
        process.exit()
    }
    ssh.disconnect()
}
