import * as yargs from 'yargs'
import { SSHService } from '../session'
import { cli } from '../cli'

exports.command = 'update'
exports.desc = 'Update Snips platform on your device'
exports.builder = {
    verbose: {
        demandOption: false,
        describe: 'Include remote logs',
        type: 'boolean',
        alias: 'v',
    },
}

exports.handler = async (argv: yargs.Argv) => {
    const verbose = JSON.parse(JSON.stringify(argv)).verbose
    const ssh = new SSHService()
    await ssh.connect()
    .catch(e => {
        cli.stream.error(e)
        process.exit()
    })

    cli.stream.println('Updating Snips Platform')
    await ssh.updateSnips(output => {
        if (verbose) { cli.stream.print(output) }
    })
        .catch(e => cli.stream.error(e))
    cli.stream.success('Finished updating the platform')
    ssh.disconnect()
    process.exit()
}
